:mod:`stix.common.vocabs` Module
==================================

.. module:: stix.common.vocabs

Classes
-------

.. autoclass:: AssetType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: AttackerInfrastructureType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: AttackerToolType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: AvailabilityLossType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: AvailabilityLossType_1_1_1
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: COAStage_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: CampaignStatus_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: CourseOfActionType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: DiscoveryMethod_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: DiscoveryMethod_2_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: HighMediumLow_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: ImpactQualification_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: ImpactRating_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: IncidentCategory_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: IncidentEffect_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: IncidentStatus_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: IndicatorType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: IndicatorType_1_1
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: InformationSourceRole_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: InformationType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: IntendedEffect_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: LocationClass_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: LossDuration_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: LossProperty_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: MalwareType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: ManagementClass_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: Motivation_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: Motivation_1_0_1
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: Motivation_1_1
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: OwnershipClass_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: PackageIntent_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: PlanningAndOperationalSupport_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: PlanningAndOperationalSupport_1_0_1
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: ReportIntent_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: SecurityCompromise_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: SystemType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: ThreatActorSophistication_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: ThreatActorType_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: Versioning_1_0
    :undoc-members:
    :members:
    :show-inheritance:

.. autoclass:: VocabString
    :show-inheritance:
    :members:

.. autoclass:: AssetType
    :show-inheritance:
    :members:

.. autoclass:: AttackerInfrastructureType
    :show-inheritance:
    :members:

.. autoclass:: AttackerToolType
    :show-inheritance:
    :members:

.. autoclass:: AvailabilityLossType
    :show-inheritance:
    :members:

.. autoclass:: CampaignStatus
    :show-inheritance:
    :members:

.. autoclass:: COAStage
    :show-inheritance:
    :members:

.. autoclass:: CourseOfActionType
    :show-inheritance:
    :members:

.. autoclass:: DiscoveryMethod
    :show-inheritance:
    :members:

.. autoclass:: HighMediumLow
    :show-inheritance:
    :members:

.. autoclass:: ImpactQualification
    :show-inheritance:
    :members:

.. autoclass:: ImpactRating
    :show-inheritance:
    :members:

.. autoclass:: IncidentCategory
    :show-inheritance:
    :members:

.. autoclass:: IncidentEffect
    :show-inheritance:
    :members:

.. autoclass:: IncidentStatus
    :show-inheritance:
    :members:

.. autoclass:: IndicatorType
    :show-inheritance:
    :members:

.. autoclass:: InformationSourceRole
    :show-inheritance:
    :members:

.. autoclass:: InformationType
    :show-inheritance:
    :members:

.. autoclass:: IntendedEffect
    :show-inheritance:
    :members:

.. autoclass:: LocationClass
    :show-inheritance:
    :members:

.. autoclass:: LossDuration
    :show-inheritance:
    :members:

.. autoclass:: LossProperty
    :show-inheritance:
    :members:

.. autoclass:: MalwareType
    :show-inheritance:
    :members:

.. autoclass:: ManagementClass
    :show-inheritance:
    :members:

.. autoclass:: Motivation
    :show-inheritance:
    :members:

.. autoclass:: OwnershipClass
    :show-inheritance:
    :members:

.. autoclass:: PackageIntent
    :show-inheritance:
    :members:

.. autoclass:: PlanningAndOperationalSupport
    :show-inheritance:
    :members:

.. autoclass:: SecurityCompromise
    :show-inheritance:
    :members:

.. autoclass:: SystemType
    :show-inheritance:
    :members:

.. autoclass:: ThreatActorSophistication
    :show-inheritance:
    :members:

.. autoclass:: ThreatActorType
    :show-inheritance:
    :members:

Functions
---------

.. autofunction:: add_vocab
.. autofunction:: register_vocab
